# 📖 Summary
- [📖 Summary](#-summary)
- [💼 About Meteojob](#-about-meteojob)
  - [😍 Why is it a big deal for Meteojob customers & partners?](#😍why-is-it-a-big-deal-for-meteojob-customers--partners)
- [🔧 How does it work?](#-how-does-it-work)
  - [📊 Data integration capabilities:](#-data-integration-capabilities)
- [🔌 Connector Actions](#-connector-actions)
- [💍 Quick Start Examples](#-quick-start-examples)
- [🔗 Useful Links](#-useful-links)
- [👏 Special Thanks](#-special-thanks)


# 💼 About Meteojob

> METEOJOB : LEADER EUROPÉEN DU MATCHING, BIG DATA ET DES ENTRETIENS VIDÉO DANS LES RH 


## 😍 Why is it a big deal for Meteojob customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Meteojob customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Meteojob customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Meteojob to a Destination of your choice.






# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Catch profile**](docs/catch_profile.md) | Imports candidates, in synchronization with Meteojob |


</p>


<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/135601200/d56b5ad9-ec02-4868-8d1b-784271cd692a width=90% height=100% >
</p>

# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :


<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/135601200/dc691f85-a3ab-4f5f-9c57-30cfd0ccf6b6 width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.


For more code details checkout connector code.


# 🔗 Useful Links

- 📄Visit [Meteojob](https://www.meteojob.com/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/meteojob) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai : Abdellahi Mezid - Software Engineer
- 🤝 Meteojob : Support Meteojob